#include <err.h>
#include <stdio.h>
#include <stdlib.h>

/* Maximum number of works in a file. */
#define MAXSIZE 1000
#define INPUT "opgave2.in"
#define OUTPUT "opgave2.out"

/* Strategy: This can be solved using dynamic programming. Because we want as
 * much works as possible the total length should be kept as short as possible.
 *
 * The solutions are made using a two dimensional array. The index [i][j] gives
 * the optimal solution when selecting i works from the first j one.
 *
 * The trivial cases are when j == i, because then all works have to be
 * selected. Of if i is one, in which case the smallest work from the first j
 * works is selected. These are easily filled in.
 *
 * After this we look when selecting the 2 works from the first three, there
 * are now two options, one is, do not use the third work, i.e.  use the same
 * value as for [2][2], or do use the third work, and use the value at [1][2] +
 * length of work 3.
 *
 * The smallest options is of course filled in. After this one can fill in the
 * value for selecting two works from the first 4, etc.
 *
 * To determine the total number of pages needed, we need to know the number of
 * pages per book, if selected work has more pages than the book has empty
 * pages, there's only one solution, fill the previous book with empty pages,
 * and start a next book, otherwise it's just added to the book.
 */

/* File descriptors. */
FILE* fd_in;
FILE* fd_out;

/* Number of test cases. */
int n;

/* Number of pages in each volume. */
int num_pages;
/* Number of volumes. */
int num_volms;
/* Total numer of pages in all volumes together = num_pages * num_volms */
int tot_size;

/* Number of available works to choose from. */
int num_works;
/* The size of each work. */
int works[MAXSIZE];

/* The solution. */
int max_num;

/* The dynamically filled table. */
int C[MAXSIZE][MAXSIZE];

/* Returns the total length in pages which are used after adding
 * work m to the already used k pages.
 */
int
length(int k, int m)
{
	if ((k % num_pages) + m <= num_pages)
		/* The book has enough free space at the end. */
		return k + m;
	else
		/* We'll have to fill the previous book and
		 * start a new book.
		 */
		return num_pages * ((k + m) / num_pages) + m;
}


/* Convenience function. */
int
min(int i, int j)
{
	return i < j ? i : j;
}

/* Exactly works out the above strategy.  At first, fill the diagional and
 * first row and after that start filling the rest of the array.
 */
void
calculatesolution()
{
	int i, j;
	/* First row. */
	C[0][0] = works[0];
	for (j = 1; j < num_works; j++)
		C[0][j] = min(C[0][j - 1], works[j]);

	/* Diagonal. */
	for (j = 1; j < num_works; j++)
		C[j][j] = length(C[j - 1][j - 1], works[j]);

	/* Now fill the rest, choose between the two possibilities,
	 * i.e. not adding the work j, or adding the work j, which
	 * are also described at the top of this file.
	 */
	for (i = 1; i < num_works; i++) {
		for (j = i + 1; j < num_works; j++) {
			C[i][j] = min(C[i][j - 1], length(C[i - 1][j - 1],
				works[j]));
		}
	}

	/* Start looking for the best solution. This is simply the first
	 * value for i in the final column for which i isn't bigger
	 * dan tot_size.
	 */
	i = num_works - 1;
	while (C[i][num_works - 1] > tot_size)
		i--;

	max_num = i + 1;
}

/* Read the number of test cases. */
void
readinput_n(void)
{
	fd_in = fopen(INPUT, "r");
	if (fd_in == NULL)
		errx(EXIT_FAILURE, "could not open %s", INPUT);
	fscanf(fd_in, "%d\n", &n);
}

/* Read one test case. */
void
readinput(void)
{
	int i;
	fscanf(fd_in, "%d\n", &num_works);
	fscanf(fd_in, "%d\n", &num_volms);
	fscanf(fd_in, "%d\n", &num_pages);
	tot_size = num_pages * num_volms;
	for (i = 0; i < num_works; i++)
		fscanf(fd_in, "%d\n", &works[i]);
}

/* Close the input. */
void
closeinput(void)
{
	fclose(fd_in);
}


/* Open the output. */
void
openoutput(void)
{
	fd_out = fopen(OUTPUT, "w");
	if (fd_out == NULL)
		errx(EXIT_FAILURE, "could not open %s", OUTPUT);
}

/* Write the output for one test case */
void
writeoutput(void)
{
	fprintf(fd_out, "%d\n", max_num);
}

/* Close the output. */
void
closeoutput(void)
{
	fclose(fd_out);
}

int
main(void)
{
	/* Read the number of test cases. */
	readinput_n();
	openoutput();
	/* Then for each test case. */
	while (n--) {
		readinput();
		calculatesolution();
		writeoutput();
	}
	/* And done. */
	closeinput();
	closeoutput();
	return 0;
}
