#include <err.h>
#include <stdio.h>
#include <stdlib.h>

#define INPUT "opgave4.in"
#define OUTPUT "opgave4.out"

#define MAXMIRRORS 1000

/* Strategy:
 * As long as there is more than one mirror (and they're on different
 * locations) the number of reachable places is infinitely large.
 *
 * There is however a better analysis.
 *
 * J is reachable  iff: J - I = c_1*(X[1] - X[0]) + ... + c_n X[N] - X[N-1])
 * where X[i] is _not_ position of the mirror, but the position of the
 * reflection from postion 0, i.e. twice the value which is in the input
 * file.
 *
 * Because the values of X[0] are ascending, we can write this, using a
 * basic number theory theorem as:
 *
 * J - I = m * gcd(X[1] - X[0], .... X[N] - X[N-1]), but only for an even
 * number of reflections.
 *
 * However, by mirroring J in X[0], we can achieve the case for an odd
 * number of reflections.
 */

/* File descriptors. */
FILE* fd_in;
FILE* fd_out;

/* Number of test cases in the file. */
int n;

/* Position of mirror i. */
int mirror_i;
/* Position of mirror j. */
int mirror_j;

/* Number of mirrors. */
int num_mir;

/* The positions of the mirrors. */
int positions[MAXMIRRORS];

/* Reachable. */
int reachable;

/* Returns the GCD of two values. */
int
gcd(int x, int y)
{
	int r, t;
	if (x < y) {
		t = x;
		x = y;
		y = t;
	}
	if (y == 0)
		return x;
	r = x % y;
	return gcd(y, r);
}

void
calculatesolution()
{
	int i;
	int cur_gcd;

	/* Special case. */
	if (num_mir == 1) {
		if (mirror_j == (positions[0] - mirror_i))
			reachable = 1;
		else
			reachable = 0;
		return;
	}

	/* At least two mirrors. */
	cur_gcd = positions[1] - positions[0];
	for (i = 2; i < num_mir; i++) {
		cur_gcd = gcd(positions[i] - positions[i-1], cur_gcd);
	}
	/* First, try with an even number of reflections. */
	if (((mirror_j - mirror_i) % cur_gcd) == 0)
		reachable = 1;
	/* Add another reflection to make an odd number even. */
	else if (((mirror_j - (positions[0] + mirror_i)) % cur_gcd) == 0)
		reachable = 1;
	/* Not possible at all. */
	else
		reachable = 0;
}

/* Read the number of test cases. */
void
readinput_n(void)
{
	fd_in = fopen(INPUT, "r");
	if (fd_in == NULL)
		errx(EXIT_FAILURE, "could not open %s", INPUT);
	fscanf(fd_in, "%d\n", &n);
}

/* Read one test case. */
void
readinput(void)
{
	int i;
	fscanf(fd_in, "%d %d\n", &mirror_i, &mirror_j);
	fscanf(fd_in, "%d\n", &num_mir);
	for (i = 0; i < num_mir; i++) {
		fscanf(fd_in, "%d\n", &positions[i]);
		positions[i] *= 2;
	}
}

/* Close the input. */
void
closeinput(void)
{
	fclose(fd_in);
}

/* Open the output. */
void
openoutput(void)
{
	fd_out = fopen(OUTPUT, "w");
	if (fd_out == NULL)
		errx(EXIT_FAILURE, "could not open %s", OUTPUT);
}

/* Write the output for one test case */
void
writeoutput(void)
{
	if (reachable)
		fprintf(fd_out, "ja\n");
	else
		fprintf(fd_out, "nee\n");
}

/* Close the output. */
void
closeoutput(void)
{
	fclose(fd_out);
}

int
main(void)
{
	/* Read the number of test cases. */
	readinput_n();
	openoutput();
	/* Then for each test case. */
	while (n--) {
		readinput();
		calculatesolution();
		writeoutput();
	}
	/* And done. */
	closeinput();
	closeoutput();
	return 0;
}
